@@ -159,12 +159,7 @@ fm_cprod <- function(..., na.rm = NULL, .blockwise = FALSE) {
     if (any(ipl_sf)) {
       lifecycle::deprecate_stop(
         when = "0.0.1",
-        what = "fm_cprod('...'='should not mix `sp` and `sf` objects')",
-        details =
-          paste0(
-            "Converting to `sp` since there was",
-            " at least one `sp` input object."
-          )
+        what = "fm_cprod('...'='should not mix `sp` and `sf` objects')"
       )
     }
   }
@@ -1225,7 +1220,7 @@ fm_int_mesh_2d.sfc_MULTILINESTRING <- function(samplers,
 #'   (default `nsub=9`, giving 100 integration points for each triangle)
 #' @returns `tibble` with columns `loc` and `weight` with
 #'   integration points for the mesh
-#' @author Finn Lindgren \email{finn.lindgren@@gmail.com}
+#' @author Finn Lindgren <Finn.Lindgren@@gmail.com>
 #' @keywords internal
 #' @export
 #' @examples
